pub const fn bundle_parser_protocols() -> &'static [&'static str]Expand description
The protocol names parse_schema_bundle accepts.
Lets a caller report or validate bundle support without hard-coding a protocol name outside this crate.
pub const fn bundle_parser_protocols() -> &'static [&'static str]The protocol names parse_schema_bundle accepts.
Lets a caller report or validate bundle support without hard-coding a protocol name outside this crate.