parse_binary

Function parse_binary 

pub fn parse_binary(
    file_path: &str,
    content: &[u8],
) -> Result<Schema, ProtocolError>
Parse a binary file into a raw file Schema.

The entire file becomes a single chunk vertex connected to the root file vertex via a chunk-of edge.

Errors

Returns ProtocolError if schema construction fails.